| Title: | Solve discounted repeated games with monetary transfers |
|---|---|
| Description: | Solve discounted repeated games with monetary transfers using the fast Algorithms develeoped by Goldluecke and Kranz (JET, 2013) |
| Authors: | Sebastian Kranz |
| Maintainer: | Sebastian Kranz <[email protected]> |
| License: | GPL >= 2.0 |
| Version: | 0.3 |
| Built: | 2026-04-08 08:57:48 UTC |
| Source: | https://github.com/skranz/repgame |
More about what it does (maybe more than one line) ~~ A concise (1-5 lines) description of the package ~~
| Package: | repgame |
| Type: | Package |
| Version: | 1.0 |
| Date: | 2014-11-03 |
| License: | What Licence is it under ? |
~~ An overview of how to use the package, including the most important functions ~~
Who wrote it
Maintainer: Who to complain to <[email protected]>
~~ Literature or other references for background information ~~
~~ Optional links to other man pages, e.g. ~~
~~ <pkg> ~~
Simple function using Rcpp
rcpp_hello_world()rcpp_hello_world()
## Not run: rcpp_hello_world() ## End(Not run)## Not run: rcpp_hello_world() ## End(Not run)